@@ -1,5 +1,5 @@
 use gumdrop::Options;
-use httpmock::{Method::GET, MockRef, MockServer};
+use httpmock::{Method::GET, Mock, MockServer};
 use std::io::{Read, Write};
 use std::net::TcpStream;
 use std::{str, thread, time};
@@ -77,7 +77,7 @@ pub async fn get_about(user: &GooseUser) -> GooseTaskResult {
 }
 
 // All tests in this file run against the following common endpoints.
-fn setup_mock_server_endpoints(server: &MockServer) -> Vec<MockRef> {
+fn setup_mock_server_endpoints(server: &MockServer) -> Vec<Mock> {
     vec![
         // First set up INDEX_PATH, store in vector at INDEX_KEY.
         server.mock(|when, then| {
@@ -111,7 +111,7 @@ fn common_build_configuration(_server: &MockServer, custom: &mut Vec<&str>) -> G
 // Helper to confirm all variations generate appropriate results.
 fn validate_one_taskset(
     goose_metrics: &GooseMetrics,
-    mock_endpoints: &[MockRef],
+    mock_endpoints: &[Mock],
     configuration: &GooseConfiguration,
     _test_type: TestType,
 ) {
